package com.xkrs.newpro.service.impl;

import com.xkrs.encapsulation.PromptMessageEnum;
import com.xkrs.newpro.dao.QcSourceDao;
import com.xkrs.newpro.model.entity.QcSourceEntity;
import com.xkrs.newpro.model.qo.QcSourceQoInsert;
import com.xkrs.newpro.model.qo.QcSourceQoQuery;
import com.xkrs.newpro.service.QcSourceService;
import com.xkrs.newpro.utils.LocalDateUtils;
import com.xkrs.newpro.utils.LocalStringUtils;
import org.springframework.context.i18n.LocaleContextHolder;

import javax.annotation.Resource;
import java.util.List;
import java.util.Locale;
import java.util.Map;

import static com.xkrs.encapsulation.OutputEncapsulation.outputEncapsulationObject;

public class QcSourceServiceImpl implements QcSourceService {

    private Locale locale = LocaleContextHolder.getLocale();

    @Resource
    private QcSourceDao qcSourceDao;

    /**
     * 添加质检数据
     */
    @Override
    public String insertQcSource(QcSourceQoInsert insertQo) {

        String batchNo = insertQo.getBatchNo();
        String machineNo = insertQo.getMachineNo();
        String materialNo = insertQo.getMaterialNo();
        String mouldNo = insertQo.getMouldNo();
        String varietyNo = insertQo.getVarietyNo();
        String qcItemNo = insertQo.getQcItemNo();
        String qcValue = insertQo.getQcValue();

        QcSourceEntity entity = new QcSourceEntity();
        entity.setCreateTime(LocalDateUtils.getCurrentSecond());
        entity.setBatchNo(LocalStringUtils.formatEmptyValue(batchNo));
        entity.setMachineNo(LocalStringUtils.formatEmptyValue(machineNo));
        entity.setMaterialNo(LocalStringUtils.formatEmptyValue(materialNo));
        entity.setMouldNo(LocalStringUtils.formatEmptyValue(mouldNo));
        entity.setVarietyNo(LocalStringUtils.formatEmptyValue(varietyNo));
        entity.setQcItemNo(LocalStringUtils.formatEmptyValue(qcItemNo));
        entity.setQcValue(LocalStringUtils.formatEmptyValue(qcValue));
        qcSourceDao.save(entity);

        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "添加成功！", locale);
    }

    /**
     * 查询质检数据
     */
    @Override
    public String queryQcSource(QcSourceQoQuery queryQo) {

        String batchNo = queryQo.getBatchNo();
        String machineNo = queryQo.getMachineNo();
        String materialNo = queryQo.getMaterialNo();
        String mouldNo = queryQo.getMouldNo();
        String varietyNo = queryQo.getVarietyNo();
        List<Map<String, Object>> resultList = qcSourceDao.queryQcSource(LocalStringUtils.formatEmptyValue(batchNo), LocalStringUtils.formatEmptyValue(machineNo), LocalStringUtils.formatEmptyValue(materialNo), LocalStringUtils.formatEmptyValue(mouldNo), LocalStringUtils.formatEmptyValue(varietyNo));
        if (resultList == null || resultList.isEmpty()) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "暂时没有该检验项目的信息！", locale);
        }

        return null;
    }
}
